import React, { createContext, useContext, useState } from "react";
import * as api from "../lib/api";
import { toast } from "react-toastify";
export const TodoContext = createContext();
export const useAppContext = () => useContext(TodoContext);

export function TodoProvider({ children }) {
  const [todo, setTodo] = useState([]);

  //POST METHOD
  async function addTodo({ title }) {
    try {
      //default isCompleted is false
      const response = await api.addTodo({ title, isCompleted: false });
      setTodo([...todo, response]);
    } catch (err) {
      toast.error(err.message);
    }
  }
  //UPDATE METHOD
  async function updateTodo({ id, title, isCompleted }) {
    try {
      const response = await api.updateTodo({ id, title, isCompleted });
      setTodo(response);
    } catch (err) {
      toast.error(err.message);
    }
  }

  //GET METHOD
  async function getTodos() {
    try {
      const response = await api.getTodos();
      setTodo(response);
    } catch (err) {
      toast.error(err.message);
    }
  }

  //DELETE METHOD
  async function deleteTodo(id) {
    try {
      const response = await api.deleteTodo(id);
      setTodo(response);
    } catch (err) {
      toast.error(err.message);
    }
  }

  const value = {
    todo,
    addTodo,
    getTodos,
    deleteTodo,
    updateTodo,
  };
  return <TodoContext.Provider value={value}>{children}</TodoContext.Provider>;
}
