import { FaTimesCircle } from "react-icons/fa";
import Checkbox from "../../base/checkbox";
import "./task.css";
import { useEffect, useRef, useState, useCallback } from "react";
import { toast } from "react-toastify";

function Task({ id = 1, title, isCompleted, onChange, onDelete }) {
  const [debouncetitle, setDebounceTitle] = useState(title);
  const [ischeck, setIsCheck] = useState(isCompleted);
  const textarea_ref = useRef(null);

  const handleDelete = (e) => {
    e.preventDefault();
    const dialog = window.confirm("Do you want to delete?");
    if (dialog) {
      onDelete({ id });
      toast.info("Task deleted");
      return true;
    }
    return false;
  };

  // (useCallback)---> to avoid calling the checkbox component without any action applied on checkbox
  const handleChange = useCallback(() => {
    setIsCheck(!ischeck);
    onChange({ id, isCompleted: !ischeck });
    // toast(`${!ischeck ? "Task completed" : "Task not completed"}`, "success");
  }, [ischeck]);

  const handleContent = (e) => {
    setDebounceTitle(e.target.value);
    const textareaRef = textarea_ref.current;

    textareaRef.addEventListener("input", function () {
      this.style.height = "auto"; // Reset the height to auto to calculate the correct scrollHeight
      const scrollHeight = this.scrollHeight;

      if (this.scrollTop === 0) {
        this.style.height = `${scrollHeight}px`;
      } else {
        // If there is overflow (a new line is created), increase the height
        this.style.height = `${scrollHeight + this.scrollTop}px`;
      }
    });

    // Optional: To ensure the textarea resizes initially if there's content
    textareaRef.dispatchEvent(new Event("input"));

    //const textarea = document.querySelector("textarea");
    //calculate the height of content  based on scrollheight
    // textarea.addEventListener("keyup", (e) => {
    //   let scheight = e.target.scrollHeight;
    //   textarea.style.height = `${scheight}px`;
    // });
  };

  //debounce
  useEffect(() => {
    //checking the content height and set on page load
    const scrollHeight = textarea_ref.current.scrollHeight;
    textarea_ref.current.style.height = `${scrollHeight}px`;
    //after 2 second it will execute
    const handler = setTimeout(() => {
      if (textarea_ref.current.value !== title) {
        onChange({ id, title: debouncetitle });
        toast.success("Task updated");
      }
    }, 2000);

    return () => {
      clearTimeout(handler);
    };
  }, [debouncetitle]);

  return (
    <div className="task-section">
      <div>
        <Checkbox
          onChange={handleChange}
          checked={ischeck}
          // disabled={ischeck}
        />

        <textarea
          ref={textarea_ref}
          className={`${ischeck ? "strike-through" : ""}`}
          value={debouncetitle}
          onChange={handleContent}
          // disabled={ischeck}
        ></textarea>
      </div>
      <FaTimesCircle className="fa-close" onClick={handleDelete} />
    </div>
  );
}

export default Task;
